# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto',
  package='github.com.metaprov.modelaapi.services.sqlqueryrun.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGgithub.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto\x12\x35github.com.metaprov.modelaapi.services.sqlqueryrun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd5\x01\n\x17ListSqlQueryRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"p\n\x18ListSqlQueryRunsResponse\x12T\n\x05items\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunList\"\x1b\n\x19\x43reateSqlQueryRunResponse\"k\n\x18\x43reateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"k\n\x18UpdateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x1b\n\x19UpdateSqlQueryRunResponse\"8\n\x15GetSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x16GetSqlQueryRunResponse\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteSqlQueryRunResponse\"h\n\x15RunSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x18\n\x16RunSqlQueryRunResponse2\xac\n\n\x12SqlQueryRunService\x12\xce\x01\n\x11ListSqlQuerieRuns\x12N.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest\x1aO.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/sqlqueryruns\x12\xd3\x01\n\x11\x43reateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/sqlqueryruns:\x01*\x12\xce\x01\n\x0eGetSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/sqlqueryruns/{name}\x12\xee\x01\n\x11UpdateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a+/v1/sqlqueryruns/{webrequest.metadata.name}:\x01*\x12\xd7\x01\n\x11\x44\x65leteSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19*\x17/v1/sqlqueryruns/{name}\x12\xd2\x01\n\x0eRunSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/v1/sqlqueryruns/{name}:runB7Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTSQLQUERYRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=444,
)

_LISTSQLQUERYRUNSREQUEST = _descriptor.Descriptor(
  name='ListSqlQueryRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSQLQUERYRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=444,
)


_LISTSQLQUERYRUNSRESPONSE = _descriptor.Descriptor(
  name='ListSqlQueryRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=558,
)


_CREATESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='CreateSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=587,
)


_CREATESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='CreateSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=696,
)


_UPDATESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='UpdateSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=805,
)


_UPDATESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=834,
)


_GETSQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='GetSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=892,
)


_GETSQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='GetSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1013,
)


_DELETESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='DeleteSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1074,
)


_DELETESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1076,
  serialized_end=1103,
)


_RUNSQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='RunSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1209,
)


_RUNSQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='RunSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1235,
)

_LISTSQLQUERYRUNSREQUEST_LABELSENTRY.containing_type = _LISTSQLQUERYRUNSREQUEST
_LISTSQLQUERYRUNSREQUEST.fields_by_name['labels'].message_type = _LISTSQLQUERYRUNSREQUEST_LABELSENTRY
_LISTSQLQUERYRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUNLIST
_CREATESQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_UPDATESQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_GETSQLQUERYRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_RUNSQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
DESCRIPTOR.message_types_by_name['ListSqlQueryRunsRequest'] = _LISTSQLQUERYRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListSqlQueryRunsResponse'] = _LISTSQLQUERYRUNSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryRunResponse'] = _CREATESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryRunRequest'] = _CREATESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunRequest'] = _UPDATESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunResponse'] = _UPDATESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetSqlQueryRunRequest'] = _GETSQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['GetSqlQueryRunResponse'] = _GETSQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunRequest'] = _DELETESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunResponse'] = _DELETESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['RunSqlQueryRunRequest'] = _RUNSQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['RunSqlQueryRunResponse'] = _RUNSQLQUERYRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListSqlQueryRunsRequest = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsRequest)
_sym_db.RegisterMessage(ListSqlQueryRunsRequest.LabelsEntry)

ListSqlQueryRunsResponse = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsResponse)

CreateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunResponse)

CreateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunRequest)

UpdateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunRequest)

UpdateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunResponse)

GetSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRunRequest)

GetSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(GetSqlQueryRunResponse)

DeleteSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunRequest)

DeleteSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunResponse)

RunSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(RunSqlQueryRunRequest)

RunSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(RunSqlQueryRunResponse)


DESCRIPTOR._options = None
_LISTSQLQUERYRUNSREQUEST_LABELSENTRY._options = None

_SQLQUERYRUNSERVICE = _descriptor.ServiceDescriptor(
  name='SqlQueryRunService',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1238,
  serialized_end=2562,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListSqlQuerieRuns',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.ListSqlQuerieRuns',
    index=0,
    containing_service=None,
    input_type=_LISTSQLQUERYRUNSREQUEST,
    output_type=_LISTSQLQUERYRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/v1/sqlqueryruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.CreateSqlQueryRun',
    index=1,
    containing_service=None,
    input_type=_CREATESQLQUERYRUNREQUEST,
    output_type=_CREATESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/sqlqueryruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.GetSqlQueryRun',
    index=2,
    containing_service=None,
    input_type=_GETSQLQUERYRUNREQUEST,
    output_type=_GETSQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/sqlqueryruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.UpdateSqlQueryRun',
    index=3,
    containing_service=None,
    input_type=_UPDATESQLQUERYRUNREQUEST,
    output_type=_UPDATESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\0020\032+/v1/sqlqueryruns/{webrequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.DeleteSqlQueryRun',
    index=4,
    containing_service=None,
    input_type=_DELETESQLQUERYRUNREQUEST,
    output_type=_DELETESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031*\027/v1/sqlqueryruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.RunSqlQueryRun',
    index=5,
    containing_service=None,
    input_type=_RUNSQLQUERYRUNREQUEST,
    output_type=_RUNSQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\033/v1/sqlqueryruns/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SQLQUERYRUNSERVICE)

DESCRIPTOR.services_by_name['SqlQueryRunService'] = _SQLQUERYRUNSERVICE

# @@protoc_insertion_point(module_scope)
