# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto',
  package='github.com.metaprov.modelaapi.services.webrequest.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/webrequest/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto\x12\x34github.com.metaprov.modelaapi.services.webrequest.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd2\x01\n\x16ListWebRequestsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x17ListWebRequestsResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestList\"\x1a\n\x18\x43reateWebRequestResponse\"i\n\x17\x43reateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"i\n\x17UpdateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x1a\n\x18UpdateWebRequestResponse\"7\n\x14GetWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x15GetWebRequestResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteWebRequestResponse\"f\n\x14RunWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x17\n\x15RunWebRequestResponse2\x86\n\n\x11WebRequestService\x12\xc7\x01\n\x0fListWebRequests\x12L.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest\x1aM.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webrequests\x12\xcd\x01\n\x10\x43reateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webrequests:\x01*\x12\xc8\x01\n\rGetWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webrequests/{name}\x12\xe8\x01\n\x10UpdateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webrequests/{prediction.metadata.name}:\x01*\x12\xd1\x01\n\x10\x44\x65leteWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webrequests/{name}\x12\xcc\x01\n\rRunWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/webrequests/{name}:runB6Z4github.com/metaprov/modelaapi/services/webrequest/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTWEBREQUESTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=438,
)

_LISTWEBREQUESTSREQUEST = _descriptor.Descriptor(
  name='ListWebRequestsRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTWEBREQUESTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=438,
)


_LISTWEBREQUESTSRESPONSE = _descriptor.Descriptor(
  name='ListWebRequestsResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=550,
)


_CREATEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='CreateWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=578,
)


_CREATEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='CreateWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=685,
)


_UPDATEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='UpdateWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=792,
)


_UPDATEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='UpdateWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=820,
)


_GETWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='GetWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=877,
)


_GETWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='GetWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=996,
)


_DELETEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='DeleteWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1056,
)


_DELETEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='DeleteWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1084,
)


_RUNWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='RunWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1188,
)


_RUNWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='RunWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1213,
)

_LISTWEBREQUESTSREQUEST_LABELSENTRY.containing_type = _LISTWEBREQUESTSREQUEST
_LISTWEBREQUESTSREQUEST.fields_by_name['labels'].message_type = _LISTWEBREQUESTSREQUEST_LABELSENTRY
_LISTWEBREQUESTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTLIST
_CREATEWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_UPDATEWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_GETWEBREQUESTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_RUNWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
DESCRIPTOR.message_types_by_name['ListWebRequestsRequest'] = _LISTWEBREQUESTSREQUEST
DESCRIPTOR.message_types_by_name['ListWebRequestsResponse'] = _LISTWEBREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestResponse'] = _CREATEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestRequest'] = _CREATEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestRequest'] = _UPDATEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestResponse'] = _UPDATEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['GetWebRequestRequest'] = _GETWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['GetWebRequestResponse'] = _GETWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWebRequestRequest'] = _DELETEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['DeleteWebRequestResponse'] = _DELETEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['RunWebRequestRequest'] = _RUNWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['RunWebRequestResponse'] = _RUNWEBREQUESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListWebRequestsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestsRequest)
_sym_db.RegisterMessage(ListWebRequestsRequest.LabelsEntry)

ListWebRequestsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestsResponse)

CreateWebRequestResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestResponse)

CreateWebRequestRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRequest)

UpdateWebRequestRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRequest)

UpdateWebRequestResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestResponse)

GetWebRequestRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRequest)

GetWebRequestResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse)
  })
_sym_db.RegisterMessage(GetWebRequestResponse)

DeleteWebRequestRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRequest)

DeleteWebRequestResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestResponse)

RunWebRequestRequest = _reflection.GeneratedProtocolMessageType('RunWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest)
  })
_sym_db.RegisterMessage(RunWebRequestRequest)

RunWebRequestResponse = _reflection.GeneratedProtocolMessageType('RunWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse)
  })
_sym_db.RegisterMessage(RunWebRequestResponse)


DESCRIPTOR._options = None
_LISTWEBREQUESTSREQUEST_LABELSENTRY._options = None

_WEBREQUESTSERVICE = _descriptor.ServiceDescriptor(
  name='WebRequestService',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1216,
  serialized_end=2502,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListWebRequests',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.ListWebRequests',
    index=0,
    containing_service=None,
    input_type=_LISTWEBREQUESTSREQUEST,
    output_type=_LISTWEBREQUESTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webrequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.CreateWebRequest',
    index=1,
    containing_service=None,
    input_type=_CREATEWEBREQUESTREQUEST,
    output_type=_CREATEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webrequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.GetWebRequest',
    index=2,
    containing_service=None,
    input_type=_GETWEBREQUESTREQUEST,
    output_type=_GETWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webrequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.UpdateWebRequest',
    index=3,
    containing_service=None,
    input_type=_UPDATEWEBREQUESTREQUEST,
    output_type=_UPDATEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webrequests/{prediction.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.DeleteWebRequest',
    index=4,
    containing_service=None,
    input_type=_DELETEWEBREQUESTREQUEST,
    output_type=_DELETEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webrequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.RunWebRequest',
    index=5,
    containing_service=None,
    input_type=_RUNWEBREQUESTREQUEST,
    output_type=_RUNWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\032/v1/webrequests/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBREQUESTSERVICE)

DESCRIPTOR.services_by_name['WebRequestService'] = _WEBREQUESTSERVICE

# @@protoc_insertion_point(module_scope)
