# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto',
  package='github.com.metaprov.modelaapi.services.predictiveapp.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/predictiveapp/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto\x12\x37github.com.metaprov.modelaapi.services.predictiveapp.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xdb\x01\n\x19ListPredictiveAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x1aListPredictiveAppsResponse\x12[\n\x05items\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveAppList\"\x1d\n\x1b\x43reatePredictiveAppResponse\"t\n\x1a\x43reatePredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"t\n\x1aUpdatePredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"\x1d\n\x1bUpdatePredictiveAppResponse\":\n\x17GetPredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x01\n\x18GetPredictiveAppResponse\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65letePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65letePredictiveAppResponse\"<\n\x19PausePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1aPausePredictiveAppResponse\"=\n\x1aResumePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumePredictiveAppResponse\"q\n\x17RunPredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"\x1a\n\x18RunPredictiveAppResponse2\xd5\x0c\n\x14PredictiveAppService\x12\xd6\x01\n\x12ListPredictiveApps\x12R.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest\x1aS.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webeequests\x12\xdc\x01\n\x13\x43reatePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webeequests:\x01*\x12\xd7\x01\n\x10GetPredictiveApp\x12P.github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest\x1aQ.github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webeequests/{name}\x12\xf7\x01\n\x13UpdatePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webeequests/{webeequest.metadata.name}:\x01*\x12\xe0\x01\n\x13\x44\x65letePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webeequests/{name}\x12\xe3\x01\n\x12PausePredictiveApp\x12R.github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest\x1aS.github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/v1/webeequests/{name}:pause\x12\xe7\x01\n\x13ResumePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/v1/webeequests/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/predictiveapp/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=461,
)

_LISTPREDICTIVEAPPSREQUEST = _descriptor.Descriptor(
  name='ListPredictiveAppsRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=461,
)


_LISTPREDICTIVEAPPSRESPONSE = _descriptor.Descriptor(
  name='ListPredictiveAppsResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=584,
)


_CREATEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='CreatePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=615,
)


_CREATEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='CreatePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=733,
)


_UPDATEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='UpdatePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=851,
)


_UPDATEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='UpdatePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=882,
)


_GETPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='GetPredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=942,
)


_GETPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='GetPredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1073,
)


_DELETEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='DeletePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1136,
)


_DELETEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='DeletePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1167,
)


_PAUSEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='PausePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1229,
)


_PAUSEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='PausePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1259,
)


_RESUMEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='ResumePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1322,
)


_RESUMEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='ResumePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1353,
)


_RUNPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='RunPredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1468,
)


_RUNPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='RunPredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1496,
)

_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY.containing_type = _LISTPREDICTIVEAPPSREQUEST
_LISTPREDICTIVEAPPSREQUEST.fields_by_name['labels'].message_type = _LISTPREDICTIVEAPPSREQUEST_LABELSENTRY
_LISTPREDICTIVEAPPSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPPLIST
_CREATEPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_UPDATEPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_GETPREDICTIVEAPPRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_RUNPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
DESCRIPTOR.message_types_by_name['ListPredictiveAppsRequest'] = _LISTPREDICTIVEAPPSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictiveAppsResponse'] = _LISTPREDICTIVEAPPSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictiveAppResponse'] = _CREATEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictiveAppRequest'] = _CREATEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictiveAppRequest'] = _UPDATEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictiveAppResponse'] = _UPDATEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictiveAppRequest'] = _GETPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['GetPredictiveAppResponse'] = _GETPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['DeletePredictiveAppRequest'] = _DELETEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictiveAppResponse'] = _DELETEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['PausePredictiveAppRequest'] = _PAUSEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['PausePredictiveAppResponse'] = _PAUSEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['ResumePredictiveAppRequest'] = _RESUMEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['ResumePredictiveAppResponse'] = _RESUMEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['RunPredictiveAppRequest'] = _RUNPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['RunPredictiveAppResponse'] = _RUNPREDICTIVEAPPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPredictiveAppsRequest = _reflection.GeneratedProtocolMessageType('ListPredictiveAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTIVEAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTIVEAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest)
  })
_sym_db.RegisterMessage(ListPredictiveAppsRequest)
_sym_db.RegisterMessage(ListPredictiveAppsRequest.LabelsEntry)

ListPredictiveAppsResponse = _reflection.GeneratedProtocolMessageType('ListPredictiveAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIVEAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse)
  })
_sym_db.RegisterMessage(ListPredictiveAppsResponse)

CreatePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('CreatePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse)
  })
_sym_db.RegisterMessage(CreatePredictiveAppResponse)

CreatePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('CreatePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest)
  })
_sym_db.RegisterMessage(CreatePredictiveAppRequest)

UpdatePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest)
  })
_sym_db.RegisterMessage(UpdatePredictiveAppRequest)

UpdatePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse)
  })
_sym_db.RegisterMessage(UpdatePredictiveAppResponse)

GetPredictiveAppRequest = _reflection.GeneratedProtocolMessageType('GetPredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest)
  })
_sym_db.RegisterMessage(GetPredictiveAppRequest)

GetPredictiveAppResponse = _reflection.GeneratedProtocolMessageType('GetPredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse)
  })
_sym_db.RegisterMessage(GetPredictiveAppResponse)

DeletePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('DeletePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest)
  })
_sym_db.RegisterMessage(DeletePredictiveAppRequest)

DeletePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('DeletePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse)
  })
_sym_db.RegisterMessage(DeletePredictiveAppResponse)

PausePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('PausePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest)
  })
_sym_db.RegisterMessage(PausePredictiveAppRequest)

PausePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('PausePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse)
  })
_sym_db.RegisterMessage(PausePredictiveAppResponse)

ResumePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('ResumePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest)
  })
_sym_db.RegisterMessage(ResumePredictiveAppRequest)

ResumePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('ResumePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse)
  })
_sym_db.RegisterMessage(ResumePredictiveAppResponse)

RunPredictiveAppRequest = _reflection.GeneratedProtocolMessageType('RunPredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest)
  })
_sym_db.RegisterMessage(RunPredictiveAppRequest)

RunPredictiveAppResponse = _reflection.GeneratedProtocolMessageType('RunPredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppResponse)
  })
_sym_db.RegisterMessage(RunPredictiveAppResponse)


DESCRIPTOR._options = None
_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY._options = None

_PREDICTIVEAPPSERVICE = _descriptor.ServiceDescriptor(
  name='PredictiveAppService',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1499,
  serialized_end=3120,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPredictiveApps',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.ListPredictiveApps',
    index=0,
    containing_service=None,
    input_type=_LISTPREDICTIVEAPPSREQUEST,
    output_type=_LISTPREDICTIVEAPPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webeequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.CreatePredictiveApp',
    index=1,
    containing_service=None,
    input_type=_CREATEPREDICTIVEAPPREQUEST,
    output_type=_CREATEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webeequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.GetPredictiveApp',
    index=2,
    containing_service=None,
    input_type=_GETPREDICTIVEAPPREQUEST,
    output_type=_GETPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.UpdatePredictiveApp',
    index=3,
    containing_service=None,
    input_type=_UPDATEPREDICTIVEAPPREQUEST,
    output_type=_UPDATEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webeequests/{webeequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.DeletePredictiveApp',
    index=4,
    containing_service=None,
    input_type=_DELETEPREDICTIVEAPPREQUEST,
    output_type=_DELETEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PausePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.PausePredictiveApp',
    index=5,
    containing_service=None,
    input_type=_PAUSEPREDICTIVEAPPREQUEST,
    output_type=_PAUSEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\034/v1/webeequests/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.ResumePredictiveApp',
    index=6,
    containing_service=None,
    input_type=_RESUMEPREDICTIVEAPPREQUEST,
    output_type=_RESUMEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\035/v1/webeequests/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTIVEAPPSERVICE)

DESCRIPTOR.services_by_name['PredictiveAppService'] = _PREDICTIVEAPPSERVICE

# @@protoc_insertion_point(module_scope)
